<?php

namespace Elementor;
use \Etn\Utils\Helper;

if (!defined('ABSPATH')) exit;


class Exhibz_Event_Ticket_Widget extends Widget_Base
{


    public $base;

    public function get_name()
    {
        return 'exhibz-event-ticket';
    }

    public function get_title()
    {
        return esc_html__('Exhibz Event Ticket ', 'exhibz');
    }

    public function get_icon()
    {
        return 'eicon-price-list';
    }

    public function get_categories()
    {
        return ['exhibz-elements'];
    }

    protected function _register_controls()
    {

        $this->start_controls_section(
            'section_tab',
            [
                'label' => esc_html__('Pricing settings', 'exhibz'),
            ]
        );

        $this->add_control(
            "event_id",
            [
                "label"     => esc_html__("Select Event", "exhibz"),
                "type"      => Controls_Manager::SELECT2,
                "multiple"  => false,
                "options"   => Helper::get_events(),
            ]
        );

        $this->add_control(
            "show_title",
            [
                "label" => esc_html__("Show Title", "exhibz"),
                "type"  => Controls_Manager::SWITCHER,
                "label_on"  => esc_html__("Show", "exhibz"),
                "label_on"  => esc_html__("Hide", "exhibz"),
                "default"   => "yes"
            ]
        );

        $this->add_control(
            "plan_title",
            [
                "label" => esc_html__("Plan Title", "exhibz"),
                "type"  => Controls_Manager::TEXT,           
            ]
        );

        $this->end_controls_section();

         //style
        $this->start_controls_section(
			'style_section',
			[
				'label' => esc_html__( 'Style Section', 'exhibz' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
        ); 
        
        $this->add_control(
			'plan_title_color',
			[
				'label' => esc_html__( 'Plan Title Color', 'exhibz' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .plan-title' => 'color: {{VALUE}}',
				],
			]
		);
        
        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'plan_typography',
                'label' => esc_html__( 'Plan Typo', 'exhibz' ),
				'selector' => '{{WRAPPER}} .plan-title',
			]
		);

        $this->add_control(
			'plan_end_color',
			[
				'label' => esc_html__( 'Plan Date Color', 'exhibz' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .end-date' => 'color: {{VALUE}}',
				],
			]
		);

        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'price_image',
				'label' => esc_html__( 'Background', 'exhibz' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => '{{WRAPPER}} .price-image',
			]
		);

        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'price_typography',
                'label' => esc_html__( 'Price Typo', 'exhibz' ),
				'selector' => '{{WRAPPER}} .etn-price-field .etn-event-form-price',
			]
		);

        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'price_typography',
                'label' => esc_html__( 'Total Price Typo', 'exhibz' ),
				'selector' => '{{WRAPPER}} .exhibz-ticket-widget .etn-total-price',
			]
		);

        $this->add_control(
			'btn_color',
			[
				'label' => esc_html__( 'Button Color', 'exhibz' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .exhibz-ticket-widget .exhibz-btn' => 'color: {{VALUE}}',
				],
			]
		);

        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'button_typography',
                'label' => esc_html__( 'Button Typo', 'exhibz' ),
				'selector' => '{{WRAPPER}} .exhibz-ticket-widget .exhibz-btn',
			]
		);

        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'wrapper_image',
				'label' => esc_html__( 'Wrapper Background', 'exhibz' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => '{{WRAPPER}} .exhibz-ticket-widget',
			]
		);

        $this->add_responsive_control(
			'wrapper_padding',
			[
				'label' => esc_html__( 'Wrapper Padding', 'exhibz' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .exhibz-ticket-widget' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

        $this->end_controls_section();
    } //Register control end

    protected function render() {
        $settings               = $this->get_settings();
        $single_event_id        = !empty( $settings['event_id'] ) ? $settings['event_id'] : 0;
        $plan_title             =  $settings["plan_title"];

        if ( class_exists( 'WooCommerce' ) ) {
            if( function_exists('wc_print_notices') ){
             wc_print_notices();
            }
         }
        ?>
        <div class="exhibz-ticket-widget etn-event-form-widget">
            <?php
            if( !empty( $settings["show_title"] ) ){
                ?>
                <div>
                    <h3 class="etn-event-form-widget-title"><?php echo esc_html( get_the_title( $single_event_id ) );?></h3>
                </div>
                <?php
            }
            
            ?>
            <?php
            if( class_exists('WooCommerce') ){
                 
                // Helper::woocommerce_ticket_widget( $single_event_id );
                $data = \Etn\Utils\Helper::single_template_options( $single_event_id );
                $etn_left_tickets = !empty( $data['etn_left_tickets'] ) ? $data['etn_left_tickets'] : 0;
                $etn_ticket_unlimited = ( isset( $data['etn_ticket_unlimited'] ) && $data['etn_ticket_unlimited'] == "no" ) ? true : false;
                $etn_ticket_price = isset( $data['etn_ticket_price']) ? $data['etn_ticket_price'] : '';
                $etn_deadline_value = isset( $data['etn_deadline_value']) ? $data['etn_deadline_value'] : '';
                $total_sold_ticket = isset( $ticket_qty ) ? intval( $ticket_qty ) : 0;
                $ticket_qty = get_post_meta( $single_event_id, "etn_sold_tickets", true );
                $is_zoom_event = get_post_meta( $single_event_id, 'etn_zoom_event', true );
                $event_options = !empty( $data['event_options']) ? $data['event_options'] : [];
                $event_title = get_the_title( $single_event_id );
                ?>
                <div class="event-registration">

                    <div class="etn-widget etn-ticket-widget ticket-widget-banner">
                        <?php
                    if ($etn_left_tickets > 0) {
                        ?>
                        <h4 class="etn-widget-title etn-title etn-form-title"> <?php echo esc_html__(" Register Now:", 'exhibz'); ?>
                        </h4>
                        <?php
                        $attendee_reg_enable = !empty( \Etn\Utils\Helper::get_option( "attendee_registration" ) ) ? true : false;
                        ?>
                        <div class="etn-row align-items-center etn-form-wrap">
                            <div class="etn-col-md-4">
                                <div class="price-image">
                                    <div class="content">
                                        <h2 class="plan-title">
                                            <?php echo esc_html($plan_title); ?>
                                        </h2>
                                        <p class="end-date">
                                            <?php esc_html_e('Until ','exhibz'); echo esc_html($etn_deadline_value); ?>
                                        </p>
                                    </div>
                                </div>
                            </div>
                            <div class="etn-col-md-8">
                                <form action="" method="post" class="etn-event-form-parent">
                                    <?php
                                    if( $attendee_reg_enable ){
                                        ?>
                                        <?php wp_nonce_field('ticket_purchase_next_step_two','ticket_purchase_next_step_two'); ?>
                                        <input name="ticket_purchase_next_step" type="hidden" value="two" />
                                        <input name="event_id" type="hidden" value="<?php echo intval($single_event_id); ?>" />
                                        <input name="event_name" type="hidden" value="<?php echo esc_html($event_title); ?>" />
                                        <?php
                                    }else{
                                        ?>
                                        <input name="add-to-cart" type="hidden" value="<?php echo intval($single_event_id); ?>" />
                                        <input name="event_name" type="hidden" value="<?php echo esc_html($event_title); ?>" />
                                        <?php
                                    }
                                    ?>
                                    <div class="etn-row text-center align-items-center">
                                        <div class="etn-col-md-6">
                                            <div class="etn-price-field">
                                                <input id="etn_product_price" class="attr-form-control etn-event-form-price etn_product_price" readonly
                                                    name="price" type="number" value="<?php echo esc_attr($etn_ticket_price); ?>" min="1" />
                                                <label for="etn_product_price">
                                                <?php echo isset($event_options["etn_price_label"]) && ( "" != $event_options["etn_price_label"]) ? esc_html($event_options["etn_price_label"]) : esc_html__('/ Seat', 'exhibz'); ?>
                                            </label>
                                            </div>
                                            <div class="etn-qty-field">
                                                <input id="etn_product_qty" class="attr-form-control etn-event-form-qty etn_product_qty" name="quantity"
                                                    type="number" value="1" min="1" data-left_ticket="<?php echo esc_html($etn_left_tickets); ?>"
                                                    data-invalid_qty_text="<?php echo esc_html__("Invalid Qty", 'exhibz');?>" />
                                            </div>
                                        
                                            <div class="etn-total-price">
                                                <div class="etn-total-price">
                                                    <?php echo esc_html__('Total Price:', 'exhibz'); ?>
                                                    <?php 
                                                        if(function_exists("get_woocommerce_currency_symbol")){
                                                            echo esc_html(get_woocommerce_currency_symbol()); 
                                                        }
                                                        ?>
                                                    <span id="etn_form_price" class="etn_form_price">
                                                        <?php echo esc_html($etn_ticket_price); ?>
                                                    </span>
                                                </div>
                                            
                                            </div>
                                            <div class="col-item">
                                                <div class="avaiable-seat etn-single-page-ticket-count-text-holder">
                                                    <?php
                                                        if ( !isset($event_options["etn_hide_seats_from_details"]) ) {
                                                    ?>
                                                    <div class="etn-form-ticket-text">
                                                        <?php
                                                    if( $etn_ticket_unlimited ){
                                                        echo esc_html__( "This event offers unlimited tickets", 'exhibz' );
                                                    }else {
                                                        echo esc_html($etn_left_tickets) . esc_html__(' seats remaining', 'exhibz');
                                                    }
                                                    ?>
                                                    </div>
                                                    <?php
                                                    } 
                                                    if( !isset($event_options["etn_hide_attendee_count_from_details"]) ){
                                                    ?>
                                                    <div class="etn-form-ticket-text">
                                                        <?php echo esc_html( $total_sold_ticket ) . esc_html__(" attendees so far.", 'exhibz'); ?>
                                                    </div>
                                                    <?php
                                                    }
                                                ?>
                                                </div>
                                                
                                            </div>
                                        </div>
                                        <div class="etn-col-md-6">
                                            <?php do_action( 'etn_before_add_to_cart_button'); ?>
                                                <?php
                                                    $show_form_button = apply_filters("etn_form_submit_visibility", true, $single_event_id);

                                                    if ($show_form_button === false) {
                                                        ?>
                                                        <small><?php echo esc_html__('Event already expired!', 'exhibz'); ?></small>
                                                        <?php
                                                    } else {
                                                        if (!isset($event_options["etn_purchase_login_required"]) || (isset($event_options["etn_purchase_login_required"]) && is_user_logged_in())) {
                                                            ?>
                                                            <button name="submit" class="exhibz-btn whitespace--normal" type="submit">
                                                                <span class="exhibz-button-text">
                                                                    <?php echo esc_html__("Grab", 'exhibz');?> 
                                                                    <span><?php echo esc_html__("Ticket", 'exhibz');?></span>
                                                                </span>
                                                                <i class="icon icon-double-angle-pointing-to-right"></i>
                                                            </button>
                                                            <?php
                                                        } else {
                                                            ?>
                                                        <small>
                                                            <?php echo esc_html__('Please', 'exhibz'); ?> <a
                                                                href="<?php echo wp_login_url( get_permalink( ) ); ?>"><?php echo esc_html__( "Login", 'exhibz' ); ?></a>
                                                            <?php echo esc_html__(' to buy ticket!', 'exhibz'); ?>
                                                        </small>
                                                    <?php
                                                        }
                                                    }
                                            ?>
                                        </div>
                                    </div>
                                    
                                    <?php do_action( 'etn_after_add_to_cart_button'); ?>
                                </form>
                            </div>
                        </div>
                        <?php

                    } else {
                        ?>
                        <h6><?php echo esc_html__('No Tickets Available!!', 'exhibz'); ?></h6>
                        <?php
                    }

                    // show if this is a zoom event
                    if( isset( $is_zoom_event ) && "on" == $is_zoom_event){
                    ?>
                        <div class="etn-zoom-event-notice">
                            <?php echo esc_html__("[Note: This event will be held on zoom. Attendee will get zoom meeting URL through email]", 'exhibz');?>
                        </div>
                        <?php
                    }
                    ?>
                    </div>
                </div>
           <?php 
            }
           ?>
        </div>
        <?php
    }
    protected function content_template(){}
}
